@@ -1,11 +1,11 @@
 #!/usr/bin/python3
 
-from lintian_brush.rules import RulesUpdater
-from lintian_brush.fixer import report_result
+from lintian_brush.rules import RulesEditor
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 
 certainty = None
 
-with RulesUpdater() as updater:
+with RulesEditor() as updater:
     for rule in updater.makefile.iter_rules(b'get-orig-source'):
         commands = rule.commands()
         if [b'uscan'] == [c.split(b' ')[0] for c in commands]:
@@ -14,10 +14,12 @@ with RulesUpdater() as updater:
             certainty = 'possible'
         rule.clear()
         updater.makefile.drop_phony(b'get-orig-source')
+        fixed_lintian_tag(
+            'source',
+            'debian-rules-contains-unnecessary-get-orig-source-target',
+            '')
 
 
 report_result(
     'Remove unnecessary get-orig-source-target.',
-    fixed_lintian_tags=[
-        'debian-rules-contains-unnecessary-get-orig-source-target'],
     certainty=certainty)
