@@ -13,8 +13,7 @@ from lintian_brush.fixer import (
     net_access_allowed,
     report_result,
     package_is_native,
-    fixed_lintian_tag,
-    override_exists,
+    LintianIssue,
     )
 from lintian_brush.watch import (
     candidates_from_setup_py,
@@ -26,7 +25,9 @@ if os.path.exists('debian/watch') or package_is_native():
     # Nothing to do here..
     sys.exit(0)
 
-if override_exists('source', 'debian-watch-file-is-missing', info=''):
+issue = LintianIssue('source', 'debian-watch-file-is-missing', info='')
+
+if not issue.should_fix():
     sys.exit(0)
 
 candidates = []
@@ -65,8 +66,6 @@ wf.entries.append(winner[0])
 
 with open('debian/watch', 'w') as f:
     wf.dump(f)
-    fixed_lintian_tag('source', 'debian-watch-file-is-missing')
+    issue.report_fixed()
 
-report_result(
-    "Add debian/watch file, using %s." % site,
-    certainty=certainty)
+report_result("Add debian/watch file, using %s." % site, certainty=certainty)
