@@ -2,7 +2,9 @@
 
 from debian.changelog import get_maintainer
 from debmutate.control import ControlEditor
-from lintian_brush.fixer import report_result, meets_minimum_certainty
+from lintian_brush.fixer import (
+    report_result, meets_minimum_certainty, fixed_lintian_tag,
+    )
 import sys
 
 # TODO(jelmer): Bump this up if there's a way that we can verify that e.g. the
@@ -18,8 +20,8 @@ with ControlEditor() as updater:
         sys.exit(0)
     maintainer = get_maintainer()
     updater.source['Maintainer'] = "%s <%s>" % maintainer
+    fixed_lintian_tag(updater.source, 'required-field', 'Maintainer')
 
 report_result(
     'Set the maintainer field to: %s <%s>.' % maintainer,
-    certainty=CERTAINTY,
-    fixed_lintian_tags=['no-maintainer-field'])
+    certainty=CERTAINTY)
