@@ -1,7 +1,8 @@
 #!/usr/bin/python3
 
-from lintian_brush.control import update_control
+from debmutate.control import ControlEditor
 from urllib.parse import urlparse
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 
 HOST_TO_VCS = {
     'github.com': 'Git',
@@ -10,24 +11,22 @@ HOST_TO_VCS = {
     }
 
 
-def fix_vcs_type(control):
-    for field in list(control):
+with ControlEditor() as updater:
+    for field in list(updater.source):
         if not field.startswith('Vcs-') or field.lower() == 'vcs-browser':
             continue
         vcs = field[4:]
-        vcs_url = control[field]
+        vcs_url = updater.source[field]
         host = urlparse(vcs_url).netloc.split('@')[-1]
         if host not in HOST_TO_VCS:
             continue
         actual_vcs = HOST_TO_VCS[host]
         if actual_vcs != vcs:
-            print(
+            fixed_lintian_tag(
+                'source', 'vcs-field-mismatch',
+                '%s != Vcs-%s %s' % (field, actual_vcs, vcs_url))
+            del updater.source["Vcs-" + vcs]
+            updater.source["Vcs-" + actual_vcs] = vcs_url
+            report_result(
                 "Changed vcs type from %s to %s based on URL." % (
                     vcs, actual_vcs))
-            del control["Vcs-" + vcs]
-            control["Vcs-" + actual_vcs] = vcs_url
-
-
-update_control(source_package_cb=fix_vcs_type)
-
-print("Fixed-Lintian-Tags: vcs-field-mismatch")
