@@ -22,6 +22,7 @@ from debian.deb822 import Deb822
 import os
 import re
 import sys
+import warnings
 
 
 def write_debhelper_rules_template(path):
@@ -59,11 +60,14 @@ def write_changelog_template(path, source_name, version, wnpp_bugs=None):
         date=format_date())
     with open(path, 'w') as f:
         f.write(cl.__str__().strip('\n') + '\n')
-        cl.write_to_open_file(f)
 
 
 async def find_wnpp_bugs(source_name):
-    from .udd import connect_udd_mirror
+    try:
+        from .udd import connect_udd_mirror
+    except ModuleNotFoundError:
+        warnings.warn('asyncpg not available, unable to find wnpp bugs.')
+        return []
     conn = await connect_udd_mirror()
     return [row[0] for row in await conn.fetch("""\
 select id from wnpp where source = $1 and type in ('ITP', 'RFP') LIMIT 1
@@ -87,10 +91,6 @@ def main(argv=None):
     breezy.initialize()
     import breezy.git  # noqa: E402
     import breezy.bzr  # noqa: E402
-    from breezy.plugins.debian.upstream.branch import (
-        upstream_branch_version,
-        upstream_version_add_revision,
-        )
     from breezy import osutils
     from breezy.commit import NullCommitReporter
 
@@ -106,7 +106,9 @@ def main(argv=None):
         )
     from lintian_brush.debhelper import maximum_debhelper_compat_version
     from lintian_brush.standards_version import iter_standards_versions
-    from lintian_brush.upstream_metadata import guess_upstream_metadata
+    from lintian_brush.upstream_metadata import (
+        get_upstream_info,
+        )
     from breezy.trace import note  # noqa: E402
 
     parser = argparse.ArgumentParser(prog='debianize')
@@ -139,6 +141,9 @@ def main(argv=None):
     parser.add_argument(
         '--check', action='store_true',
         help='Check guessed metadata against external sources.')
+    parser.add_argument(
+        '--force-subprocess', action='store_true',
+        help=argparse.SUPPRESS)
     parser.add_argument('binary', type=str, nargs='*')
 
     minimum_certainty = 'possible'  # For now..
@@ -155,7 +160,7 @@ def main(argv=None):
 
     use_inotify = (False if args.disable_inotify else None),
     try:
-        check_clean_tree(wt)
+        check_clean_tree(wt, wt.basis_tree(), subpath)
     except PendingChanges:
         note("%s: Please commit pending changes first.", wt.basedir)
         return 1
@@ -169,10 +174,12 @@ def main(argv=None):
              'Run lintian-brush instead?', wt.abspath(subpath))
         return 1
 
-    metadata = guess_upstream_metadata(
-        '.', args.trust, not args.disable_net_access,
-        consult_external_directory=args.consult_external_directory,
-        check=args.check)
+    buildsystem, unused_requirements, metadata = (
+        get_upstream_info(
+            '.', trust_package=args.trust,
+            net_access=not args.disable_net_access,
+            consult_external_directory=args.consult_external_directory,
+            check=args.check))
 
     try:
         upstream_name = metadata['Name']
@@ -199,18 +206,25 @@ def main(argv=None):
         wnpp_bugs = None
 
     with wt.lock_write():
-        upstream_version = upstream_branch_version(
-            wt.branch, wt.last_revision(), source_name)
-        if upstream_version is None and 'X-Version' in metadata:
-            # They haven't done any releases yet. Assume we're ahead of the
-            # next announced release?
-            next_upstream_version = metadata['X-Version']
-            upstream_version = upstream_version_add_revision(
-                wt.branch, next_upstream_version, wt.last_revision(),
-                '~')
+        try:
+            from breezy.plugins.debian.upstream.branch import (
+                upstream_branch_version,
+                upstream_version_add_revision,
+                )
+        except ModuleNotFoundError:
+            note('Install breezy-debian for upstream version guessing.')
+        else:
+            upstream_version = upstream_branch_version(
+                wt.branch, wt.last_revision(), source_name)
+            if upstream_version is None and 'X-Version' in metadata:
+                # They haven't done any releases yet. Assume we're ahead of the
+                # next announced release?
+                next_upstream_version = metadata['X-Version']
+                upstream_version = upstream_version_add_revision(
+                    wt.branch, next_upstream_version, wt.last_revision(),
+                    '~')
         if upstream_version is None:
-            note('Unable to determine upstream version.')
-            return 1
+            note('Unable to determine upstream version, using 0.')
 
         version = Version(upstream_version + '-1')
         source = Deb822()
@@ -233,19 +247,18 @@ def main(argv=None):
             'debhelper-compat (= %d)' % maximum_debhelper_compat_version(
                 compat_release))
 
+        initial_files = []
         try:
             wt.mkdir(osutils.pathjoin(subpath, 'debian'))
             write_debhelper_rules_template('debian/rules')
+            initial_files.append('debian/rules')
             write_control_template('debian/control', source, binaries)
+            initial_files.append('debian/control')
             write_changelog_template(
                 'debian/changelog', source_name, version, wnpp_bugs)
+            initial_files.append('debian/changelog')
 
-            initial_files = [
-                osutils.pathjoin(subpath, p)
-                for p in [
-                    'debian/changelog', 'debian/control',
-                    'debian/rules']]
-            wt.add(initial_files)
+            wt.add([osutils.pathjoin(subpath, p) for p in initial_files])
 
             wt.commit(
                 'Create debian/ directory', allow_pointless=False,
@@ -253,10 +266,12 @@ def main(argv=None):
                 specific_files=initial_files,
                 reporter=NullCommitReporter())
         except BaseException:
-            reset_tree(wt, dirty_tracker, subpath)
+            reset_tree(
+                wt, wt.basis_tree(), subpath, dirty_tracker=dirty_tracker)
             raise
 
-        fixers = available_lintian_fixers()
+        fixers = available_lintian_fixers(
+            force_subprocess=args.force_subprocess)
 
         run_lintian_fixers(
             wt, fixers,
