@@ -17,6 +17,7 @@
 
 """Tests for lintian_brush."""
 
+from datetime import datetime
 import os
 import re
 import sys
@@ -43,6 +44,7 @@ from lintian_brush import (
     PendingChanges,
     PythonScriptFixer,
     ScriptFixer,
+    FailedPatchManipulation,
     UnsupportedCertainty,
     available_lintian_fixers,
     check_clean_tree,
@@ -58,11 +60,12 @@ from lintian_brush import (
     run_lintian_fixers,
     select_fixers,
     version_string,
+    ManyResult,
     )
 
 
 CHANGELOG_FILE = ('debian/changelog', """\
-blah (0.1) UNRELEASED; urgency=medium
+blah (%(version)s) UNRELEASED; urgency=medium
 
   * Initial release. (Closes: #911016)
 
@@ -97,7 +100,7 @@ Lintian-Tags: i-fix-another-tag, no-extension
 
 class CheckCleanTreeTests(TestCaseWithTransport):
 
-    def make_test_tree(self, format=None):
+    def make_test_tree(self, format=None, version='0.1'):
         tree = self.make_branch_and_tree('.', format=format)
         self.build_tree_contents([
             ('debian/', ),
@@ -110,7 +113,7 @@ Binary: blah
 Arch: all
 
 """),
-            CHANGELOG_FILE])
+            (CHANGELOG_FILE[0], CHANGELOG_FILE[1] % {'version': version})])
         tree.add(['debian', 'debian/changelog', 'debian/control'])
         tree.commit('Initial thingy.')
         return tree
@@ -120,7 +123,7 @@ Arch: all
         self.build_tree_contents([('debian/changelog', 'blah')])
         with tree.lock_write():
             self.assertRaises(
-                PendingChanges, check_clean_tree, tree)
+                PendingChanges, check_clean_tree, tree, tree.basis_tree())
 
     def test_pending_changes_bzr_empty_dir(self):
         # See https://bugs.debian.org/914038
@@ -128,14 +131,14 @@ Arch: all
         self.build_tree_contents([('debian/upstream/', )])
         with tree.lock_write():
             self.assertRaises(
-                PendingChanges, check_clean_tree, tree)
+                PendingChanges, check_clean_tree, tree, tree.basis_tree())
 
     def test_pending_changes_git_empty_dir(self):
         # See https://bugs.debian.org/914038
         tree = self.make_test_tree(format='git')
         self.build_tree_contents([('debian/upstream/', )])
         with tree.lock_write():
-            check_clean_tree(tree)
+            check_clean_tree(tree, tree.basis_tree())
 
     def test_pending_changes_git_dir_with_ignored(self):
         # See https://bugs.debian.org/914038
@@ -148,7 +151,7 @@ Arch: all
         tree.add('.gitignore')
         tree.commit('add gitignore')
         with tree.lock_write():
-            check_clean_tree(tree)
+            check_clean_tree(tree, tree.basis_tree())
 
     def test_extra(self):
         tree = self.make_test_tree()
@@ -156,7 +159,31 @@ Arch: all
         with tree.lock_write():
             self.assertRaises(
                 PendingChanges, check_clean_tree,
-                tree)
+                tree, tree.basis_tree())
+
+    def test_subpath(self):
+        tree = self.make_test_tree()
+        self.build_tree_contents(
+            [('debian/foo', 'blah'), ('foo/', )])
+        tree.add('foo')
+        tree.commit('add foo')
+        with tree.lock_write():
+            check_clean_tree(tree, tree.basis_tree(), subpath='foo')
+            self.assertRaises(
+                PendingChanges, check_clean_tree,
+                tree, tree.basis_tree(), subpath='')
+
+    def test_subpath_changed(self):
+        tree = self.make_test_tree()
+        self.build_tree_contents([('foo/', )])
+        tree.add('foo')
+        tree.commit('add foo')
+        self.build_tree_contents([('debian/control', 'blah')])
+        with tree.lock_write():
+            check_clean_tree(tree, tree.basis_tree(), subpath='foo')
+            self.assertRaises(
+                PendingChanges, check_clean_tree,
+                tree, tree.basis_tree(), subpath='')
 
 
 class DummyFixer(Fixer):
@@ -180,7 +207,7 @@ class FailingFixer(Fixer):
 
 class RunLintianFixerTests(TestCaseWithTransport):
 
-    def make_test_tree(self, format=None):
+    def make_test_tree(self, format=None, version='0.1'):
         tree = self.make_branch_and_tree('.', format=format)
         self.build_tree_contents([
             ('debian/', ),
@@ -193,7 +220,7 @@ Binary: blah
 Arch: all
 
 """),
-            CHANGELOG_FILE])
+            (CHANGELOG_FILE[0], CHANGELOG_FILE[1] % {'version': version})])
         tree.add(['debian', 'debian/changelog', 'debian/control'])
         tree.commit('Initial thingy.')
         return tree
@@ -336,6 +363,78 @@ Arch: all
             self.assertEqual(
                 [], list(tree.iter_changes(tree.basis_tree())))
 
+    def test_upstream_change(self):
+        tree = self.make_test_tree(version='0.1-1')
+
+        class NewFileFixer(Fixer):
+            def run(self, basedir, package, *args, **kwargs):
+                with open(os.path.join(basedir, 'configure.ac'), 'w') as f:
+                    f.write("AC_INIT(foo, bar)\n")
+                return FixerResult(
+                    "Created new configure.ac.", [],
+                    patch_name='add-config')
+        with tree.lock_write():
+            result, summary = run_lintian_fixer(
+                tree, NewFileFixer('add-config', 'add-config'),
+                update_changelog=False,
+                timestamp=datetime(2020, 9, 8, 0, 36, 35, 857836))
+        self.assertEqual(
+            summary,
+            'Add patch add-config.patch: Created new configure.ac.')
+        self.assertIs(None, result.certainty)
+        self.assertEqual([], result.fixed_lintian_tags)
+        rev = tree.branch.repository.get_revision(tree.last_revision())
+        self.assertEqual(rev.message, (
+            'Created new configure.ac.\n'
+            '\n'
+            'Changes-By: lintian-brush\n'))
+        self.assertEqual(2, tree.branch.revno())
+        basis_tree = tree.branch.basis_tree()
+        with basis_tree.lock_read():
+            self.assertEqual(
+                basis_tree.get_file_text('debian/patches/series'),
+                b'add-config.patch\n')
+            lines = basis_tree.get_file_lines(
+                'debian/patches/add-config.patch')
+        self.assertEqual(lines[0], b'Description: Created new configure.ac.\n')
+        self.assertEqual(lines[1], b'Origin: other\n')
+        self.assertEqual(lines[2], b'Last-Update: 2020-09-08\n')
+        self.assertEqual(lines[3], b'\n')
+        self.assertEqual(lines[4], b'=== added file \'configure.ac\'\n')
+        self.assertEqual(lines[7], b'@@ -0,0 +1,1 @@\n')
+        self.assertEqual(lines[8], b'+AC_INIT(foo, bar)\n')
+
+    def test_upstream_change_stacked(self):
+        tree = self.make_test_tree(version='0.1-1')
+
+        self.build_tree_contents([
+            ('debian/patches/', ),
+            ('debian/patches/series', 'foo\n'),
+            ('debian/patches/foo', """\
+--- /dev/null	2020-09-07 13:26:27.546468905 +0000
++++ a	2020-09-08 01:26:25.811742671 +0000
+@@ -0,0 +1 @@
++foo
+""")])
+        tree.add(
+            ['debian/patches', 'debian/patches/series', 'debian/patches/foo'])
+        tree.commit('Add patches')
+
+        class NewFileFixer(Fixer):
+            def run(self, basedir, package, *args, **kwargs):
+                with open(os.path.join(basedir, 'configure.ac'), 'w') as f:
+                    f.write("AC_INIT(foo, bar)\n")
+                return FixerResult(
+                    "Created new configure.ac.", [],
+                    patch_name='add-config')
+        with tree.lock_write():
+            self.assertRaises(
+                FailedPatchManipulation,
+                run_lintian_fixer,
+                tree, NewFileFixer('add-config', 'add-config'),
+                update_changelog=False,
+                timestamp=datetime(2020, 9, 8, 0, 36, 35, 857836))
+
 
 class RunLintianFixersTests(TestCaseWithTransport):
 
@@ -353,7 +452,7 @@ Binary: blah
 Arch: all
 
 """),
-            CHANGELOG_FILE])
+            (CHANGELOG_FILE[0], CHANGELOG_FILE[1] % {'version': '0.1'})])
         self.tree.add(['debian', 'debian/changelog', 'debian/control'])
         self.tree.commit('Initial thingy.')
 
@@ -398,7 +497,7 @@ Arch: all
 
 class HonorsVcsCommitter(TestCaseWithTransport):
 
-    def make_package_tree(self, format):
+    def make_package_tree(self, format, version='0.1'):
         tree = self.make_branch_and_tree('.', format=format)
         self.build_tree_contents([
             ('debian/', ),
@@ -411,7 +510,7 @@ Binary: blah
 Arch: all
 
 """),
-            CHANGELOG_FILE])
+            (CHANGELOG_FILE[0], CHANGELOG_FILE[1] % {'version': version})])
         tree.add(['debian', 'debian/changelog', 'debian/control'])
         tree.commit('Initial thingy.')
         return tree
@@ -502,7 +601,7 @@ blah (0.1) unstable; urgency=medium
         with tree.lock_read(), basis_tree.lock_read():
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog', changes))
+            tree, tree.basis_tree(), 'debian/changelog', changes))
 
     def test_other_change(self):
         tree = self.make_package_tree()
@@ -520,7 +619,7 @@ Arch: all
         with tree.lock_read(), basis_tree.lock_read():
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog', changes))
+            tree, tree.basis_tree(), 'debian/changelog', changes))
 
     def test_other_changes(self):
         tree = self.make_package_tree()
@@ -546,7 +645,7 @@ blah (0.1) UNRELEASED; urgency=medium
         with tree.lock_read(), basis_tree.lock_read():
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog', changes))
+            tree, tree.basis_tree(), 'debian/changelog', changes))
 
     def test_changes_to_other_changelog_entries(self):
         tree = self.make_package_tree()
@@ -568,7 +667,7 @@ blah (0.1) unstable; urgency=medium
         with tree.lock_read(), basis_tree.lock_read():
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog', changes))
+            tree, tree.basis_tree(), 'debian/changelog', changes))
 
     def test_changes_to_last_only(self):
         tree = self.make_package_tree()
@@ -591,7 +690,25 @@ blah (0.1) unstable; urgency=medium
         with tree.lock_read(), basis_tree.lock_read():
             changes = tree.iter_changes(basis_tree)
         self.assertTrue(only_changes_last_changelog_block(
-            tree, 'debian/changelog', changes))
+            tree, tree.basis_tree(), 'debian/changelog', changes))
+
+    def test_only_new_changelog(self):
+        tree = self.make_branch_and_tree('.', format='git')
+        self.build_tree_contents([
+            ('debian/', ),
+            ('debian/changelog', """\
+blah (0.1) unstable; urgency=medium
+
+  * Initial release. (Closes: #911016)
+
+ -- Blah <example@debian.org>  Sat, 13 Oct 2018 11:21:39 +0100
+""")])
+        basis_tree = tree.basis_tree()
+        with tree.lock_write(), basis_tree.lock_read():
+            tree.add(['debian', 'debian/changelog'])
+            changes = tree.iter_changes(basis_tree)
+            self.assertTrue(only_changes_last_changelog_block(
+                tree, basis_tree, 'debian/changelog', changes))
 
     def test_changes_to_last_only_but_released(self):
         tree = self.make_package_tree()
@@ -629,7 +746,7 @@ blah (0.1) unstable; urgency=medium
         with tree.lock_read(), basis_tree.lock_read():
             changes = tree.iter_changes(basis_tree)
         self.assertFalse(only_changes_last_changelog_block(
-            tree, 'debian/changelog', changes))
+            tree, tree.basis_tree(), 'debian/changelog', changes))
 
 
 class LintianBrushVersion(TestCase):
@@ -858,3 +975,26 @@ class SelectFixersTests(TestCase):
                 [DummyFixer('dummy1', 'some-tag'),
                  DummyFixer('dummy2', 'other-tag')],
                 ['dummy1', 'dummy2'], ['dummy2'])])
+
+
+class ManyResultTests(TestCase):
+
+    def test_empty(self):
+        result = ManyResult()
+        self.assertEqual('certain', result.minimum_success_certainty())
+        self.assertEqual(([], {}), tuple(result))
+
+    def test_no_certainty(self):
+        result = ManyResult()
+        result.success.append(
+            (FixerResult('Do bla', ['tag-a'], None), 'summary'))
+        self.assertEqual('certain', result.minimum_success_certainty())
+        self.assertEqual((result.success, {}), tuple(result))
+
+    def test_possible(self):
+        result = ManyResult()
+        result.success.append(
+            (FixerResult('Do bla', ['tag-a'], 'possible'), 'summary'))
+        result.success.append(
+            (FixerResult('Do bloeh', ['tag-b'], 'certain'), 'summary'))
+        self.assertEqual('possible', result.minimum_success_certainty())
